"""
Calcule et trace les positions des 4 satellites galileens, relativement à Jupiter.
L'échelle en x est en rayon de Jupiter.
Auteur : David Alberto (www.astrolabe-science.fr)
"""
import ephem#calculs d'éphémérides astronomiques
import matplotlib.pyplot as plt#graphes
import datetime as dt#gestion des dates
import matplotlib.dates as mdates#format des graduations de dates

#--------------------------------------------------------------------------
#Création de dates limites et d'une liste de dates:

date_debut=dt.datetime(2022, 1, 4)#année, mois, jour,heure,min,secondes
date_fin=dt.datetime(2022, 1, 14)#année, mois, jour,heure,min,secondes
pas=dt.timedelta(hours=1)#modifiable. Possible aussi : days=1, hours=2...
"""
Les heures sont en temps universel TU.
Si on indique la date, sans l'heure, c'est 00h00min00s.
Si on veut une heure précise, on indique année, mois, jour, heures, minutes, secondes.
Certaines positions varient beaucoup en quelques heures.
"""

date=date_debut
epoque=[]
while date<=date_fin:
    epoque.append(date)
    date=date+pas
#--------------------------------------------------------------
plt.rcParams["font.family"] = "Ubuntu"#ou autre police installée sur l'ordinateur

listeSatellites={#avec leur couleur associée
'Io': 'orangered', 
'Europe':'purple', 
'Ganymède': 'royalblue', 
'Callisto':'tan'
}

fig=plt.figure(tight_layout=True)#marges réduites
ax=plt.subplot()
ax.set_title("Positions des satellites galiléens relativement à Jupiter")
fig.set_size_inches(21/2.54, 29.7/2.54)#format A4 portrait
ax.invert_yaxis()#inversion de l'axe y (augmentation vers le bas)
ax.set_ylim(date_fin, date_debut)#ordre cohérent avec l'inversion
ax.set_xlabel("Position (en rayon de Jupiter)")
#ax.set_xlim(-25, 25)
#ax.set_xticks([])#suppression des graduations en x
#Mise en forme des graduations de dates :
locator1 = mdates.AutoDateLocator(minticks=10, maxticks=25)#paramètres à régler par tâtonnements, selon la longueur de la période choisie
heures=mdates.HourLocator(byhour=(6, 12, 18))#graduation secondaire toutes les 6 heures
formatter = mdates.ConciseDateFormatter(locator1)
ax.yaxis.set_major_locator(locator1)
ax.yaxis.set_major_formatter(formatter)
ax.yaxis.set_minor_locator(heures)

for satellite in list(listeSatellites):
    positions=[]
    for date in epoque:
        if satellite=='Io':
            coord=ephem.Io(date)
        elif satellite=='Europe':
            coord=ephem.Europa(date)
        elif satellite=='Ganymède':
            coord=ephem.Ganymede(date)
        else:
           coord=ephem.Callisto(date)
        positions.append(coord.x)
    ax.plot(positions, epoque, label=satellite, c=listeSatellites[satellite])

ax.axvline(0, lw=2, c='k')#ligne verticale sur 0
plt.legend()
plt.grid(which='minor', alpha=0.5)
plt.grid(which='major')
fig.text(0.01, 0.01, "D. Alberto (www.astrolabe-science.fr)", fontsize=8)
fig.savefig("PeriodesSatellitesGalileens.pdf")
fig.savefig("PeriodesSatellitesGalileens.png", dpi=200)
#plt.show()
